<script setup>
import { Head, Link, useForm } from '@inertiajs/inertia-vue3';
import Welcome from '@/Jetstream/Welcome.vue';
import JetLabel from '@/Jetstream/Label.vue';
import Datepicker from '@vuepic/vue-datepicker';
import '@vuepic/vue-datepicker/dist/main.css';
import JetDropdown from '@/Jetstream/Dropdown.vue';
import JetDropdownLink from '@/Jetstream/DropdownLink.vue';
import JetModal from '@/Jetstream/Modal.vue';
import JetButton from '@/Jetstream/Button.vue';
import mapboxgl from 'mapbox-gl';
import 'mapbox-gl/dist/mapbox-gl.css';
import DK_Button from '@/components/dk_Button.vue';
import DK_Input from '@/components/dk_Input.vue';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}
</script>

<style>

/*///////////*/

#scoped-component .dp__input_reg {
    text-align: right;
    background: none;
    border-width: 0px !important;
    border-color: transparent;
    border-radius: 0.5rem;
    padding-right: 0;
    color: #FFFAFA !important;
    padding: 0;
}

#scoped-component .dp__input_icons {
    display: none;
}



.dp__theme_light {
    --dp-background-color: rgba(0, 57, 93, 0.95);
    --dp-text-color: #FFFAFA;
    --dp-hover-color: rgba(0, 255, 255, 0.2);
    --dp-hover-text-color: #FFFAFA;
    --dp-hover-icon-color: #e3e3e3;
    --dp-primary-color: rgba(0, 255, 255, 0.5);
    --dp-primary-text-color: #FFFAFA;
    --dp-secondary-color: #959595;
    --dp-border-color: #FFFAFA;
    --dp-menu-border-color: #FFFAFA;
    --dp-border-color-hover: #FFFAFA;
    --dp-disabled-color: #959595;
    --dp-scroll-bar-background: #f3f3f3;
    --dp-scroll-bar-color: #959595;
    --dp-success-color: rgba(5, 255, 243, 0.7);
    --dp-success-color-disabled: rgba(5, 255, 243, 0.7);
    --dp-icon-color: #e3e3e3;
    --dp-danger-color: #e6002e;
    --dp-highlight-color: rgba(25, 118, 210, 0.1);
}

.dp__preset_range {
    color: #e3e3e3;
}

.dp__action {
    font-weight: 400;
    font-size: x-large;
}

.dp__button {
    background: none;
}

.dp__action_row {
    border-radius: 0.5rem;
    background: none;
    padding-top: 0;
    display: flex;
    justify-content: flex-end;
}

.dp__menu_index {
    border-radius: 0.5rem;
}

.dp__cancel {
    display: none;
    color: #e6002e;
}

.dp__selection_preview {
    display: none;
}

.dp__input {
    font-size: 0.95rem;
}

.dp__pointer {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
}

.dp__arrow_top {
    display: none;
}

.highcharts-exporting-group{
    display: none;
}

/* Radio */

input[type="radio"] {
    background-color: transparent;
    border-radius: 10px;
    cursor: pointer;
    display: inline-block;
    height: 15px;
    position: relative;
    width: 15px;
    -webkit-appearance: none;
}

input[type="radio"]:after {
    background-color: rgba(5, 255, 243, 0.1);
    border-radius: 25px;

    content: '';
    display: block;
    height: 10px;
    left: 4px;
    position: relative;
    top: 4px;
    width: 10px;
    border-width: 1px;
    border-color: rgba(175, 175, 175, 0.75);
}

input[type="radio"]:checked:after {
    background-color: rgba(5,255,243, 0.8);
    border-color: rgba(255, 250, 250, 0.9);
}

input[type="radio"]:hover:after {
    border-color: rgba(255, 250, 250, 0.65) ;
}

@keyframes pulse {

    0%,
    100% {
        opacity: 1;
    }

    50% {
        opacity: 0;
    }
}

</style>

<template>
    <AppLayout title="Profile">
        <div v-if="this.screen_width >= 768" style="height: calc(100vh - 4.75rem);"
            class="bg-darkblue-background px-8 z-0 overflow-y-scroll cursor-default">

            <div class="flex flex-col justify-between items-start w-full">
                <div class="grid grid-cols-2 w-full">
                    <div class="flex gap-2 items-start justify-start w-full mt-4">
                        <p class="text-white-snow font-light text-2xl w-full text-left">{{ this.$t('general.Profile Information') }}</p>
                    </div>
                    <div class="flex gap-2 items-end justify-end w-full">
                        <div class="flex items-start justify-end">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_Readings', { id:  this.data.id })" >

                                <DK_Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')">
                                    {{ this.$t("general.Readings") }}
                                </DK_Button>

                            </Link>
                        </div>
                        <div class="flex items-start justify-end">

                            <DK_Button class="pt-6" color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                {{ this.$t("general.Back") }}
                            </DK_Button>

                        </div>
                    </div>
                </div>

                <div v-bind:class="{ 'hidden': !(this.data.RSSI == null && this.data.Battery == null)}" class="flex gap-2 whitespace-nowrap items-baseline">
                    <i class="fa-solid fa-triangle-exclamation" style="font-size:0.8rem; color:rgba(224,191,52,1);"></i>
                    <p class="font-light text-sm text-white-snow flex whitespace-nowrap">
                        {{ this.$t('text.No records were found for the device') }}
                    </p>
                </div>

            </div>

            <div class="grid 2xl:grid-cols-5 grid-cols-4 pb-6 pt-4">
                <div class="col-span-1 text-center text-white-snow baltoro-container p-4 h-fit flex justify-between flex-col 2xl:gap-10 gap-8 mr-3">
                    <div>
                        <p class="text-md text-center text-cyan-text font-light whitespace-nowrap pb-2">
                            {{ this.$t("general." + "Gateway") }}
                        </p>
                        <div class="grid grid-rows-1 pt-1 mb-2">
                            <div class="flex row-span-1 justify-between text-md pt-1 text-white-snow font-light">
                                <div class="text-left" style="margin-top:0.2rem">
                                    <p class="text-gray-light font-semibold">Movistar</p>
                                </div>
                                <div class="text-right">
                                    <!-- Coverage SVG -->
                                    <i v-if="this.data.RSSI <= 110" class="DK-signal-01"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else-if="this.data.RSSI <= 100" class="DK-signal-02"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else-if="this.data.RSSI <= 85" class="DK-signal-03"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else-if="this.data.RSSI <= 70" class="DK-signal-04"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                    <i v-else class="DK-signal-05"
                                        style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>

                                    <!-- Battery -->
                                    <i v-if="this.data.Battery <= 2900" class="DK-Batt-25 animate-pulse"
                                        style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem;  margin-left:0.5rem; position:relative; top:10%"></i>
                                    <i v-else-if="this.data.Battery <= 3100" class="DK-Batt-50"
                                        style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                    <i v-else-if="this.data.Battery <= 3300" class="DK-Batt-75"
                                        style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                    <i v-else class="DK-Batt-100"
                                        style="font-size:1.5rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:10%"></i>
                                </div>
                            </div>
                        </div>

                        <div class="flex justify-center items-center relative h-[15rem]">
                            <img v-if="this.data.type_name.indexOf('PIPE20XL') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20XL_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20L') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20W') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20P') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20P_perspec.png" />
                            <img v-else-if="this.data.type_name.indexOf('PIPE20') != -1" class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />
                            <img v-else class="2xl:max-h-60 md:max-h-40 pb-6"
                                src="\assets\images\devices\PIPE20W_perspec.png" />

                            <p class="text-gray-light font-semibold text-center absolute bottom-0 left-0 right-0 z-50">{{ this.data.type_name.replace(/_/g, " ") + ' - ' + this.data.version_firmware }}</p>
                        </div>

                    </div>

                    <div class="grid gap-0.5">

                        <div class="flex justify-between text-md text-white-snow font-light">
                            <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Name") }}</p>
                            <DK_Input id="id_gateway_name" type="text" @input="this.GatewayChange()" :value="this.data.name" :border="false" textPosition="right"/>
                        </div>
                        <div class="flex justify-between text-md text-white-snow font-light">
                            <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "GatewayID") }}</p>
                            <DK_Input width="7rem" type="text" :value="this.data.id" :border="false" textPosition="right" :readonly="true"/>
                        </div>
                        <div class="flex justify-between text-md text-white-snow font-light">
                            <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Group") }}</p>
                            <DK_Input type="text" :value="this.data.group_name" :border="false" textPosition="right" :readonly="true"/>
                        </div>
                    </div>

                    <div class="rounded-md border border-gray-semimedium">
                        <div class="2xl:h-[15rem] h-[12rem] rounded-md" id="map" v-on:click="this.openMapconfig()"/>

                        <JetModal :show="this.Mapconfig" :closeable="false">

                            <p class="text-md text-center text-cyan-text font-light whitespace-nowrap p-2">
                                {{ this.$t("general." + "Edit location") }}
                            </p>

                            <div class="h-[22.5rem] w-full" id="mapModal"/>

                            <div class="grid grid-cols-3 gap-4 p-2">

                                <div class="flex justify-center text-md py-1 text-white-snow font-light gap-2">
                                    <p class="text-right text-cyan-text">{{ this.$t("general." + "Latitude") }}:</p>
                                    <DK_Input id="id_lat" type="text" @input="this.MapChange()" width="6rem" :value="this.data.GPS_lat" :border="false" textPosition="center" v-on:keyup="updateLocation()"/>
                                </div>

                                <div class="flex justify-center text-md py-1 text-white-snow font-light gap-2">
                                    <p class="text-right text-cyan-text">{{ this.$t("general." + "Longitude") }}:</p>
                                    <DK_Input id="id_lng" type="text" @input="this.MapChange()" width="6rem" :value="this.data.GPS_lng" :border="false" textPosition="center" v-on:keyup="updateLocation()"/>
                                </div>

                                <div class="flex justify-end items-center">
                                    <div class="flex gap-2">

                                        <DK_Button color="blue" :fixedSize="true"  :disabled="this.MapChange_var" v-on:click="this.SaveMap()">
                                            {{ this.$t("general.Save") }}
                                        </DK_Button>

                                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelMap()">
                                            {{ this.$t("general.Cancel") }}
                                        </DK_Button>

                                    </div>
                                </div>
                            </div>

                        </JetModal>
                    </div>

                    <div class="flex justify-end items-end gap-4" v-if="this.GatewayChange_var">
                        <div class="flex gap-2">

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveGateway()">
                                {{ this.$t("general.Save") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelGateway()">
                                {{ this.$t("general.Cancel") }}
                            </DK_Button>

                        </div>
                    </div>
                </div>

                <div class="col-span-1 text-center text-white-snow baltoro-container-l p-4 h-fit flex justify-start flex-col 2xl:gap-10 gap-8 ml-3">
                    <div>
                        <p class="text-md text-center text-cyan-text font-light whitespace-nowrap pb-2">
                            {{ this.$t("general." + "Meter") }}
                        </p>
                        <div class="grid grid-rows-1 pt-1 mb-2 h-9">
                            <div class="flex row-span-1 justify-between text-md pt-1 text-white-snow font-light">
                                <div class="text-left" style="margin-top:0.2rem">
                                    <p class="text-gray-light font-semibold"></p>
                                </div><div class="text-left" style="margin-top:0.2rem">
                                    <p class="text-gray-light font-semibold"></p>
                                </div>
                            </div>
                        </div>
                        <div class="flex justify-center items-center relative h-[15rem]">
                            <!--<img id="attachment" class="2xl:max-h-60 md:max-h-40 pb-6" :src="'../assets/images/meters/' + this.image.name" />-->
                            <img v-if="this.imageExists" id="attachment" :src="'../assets/images/meters/' + this.image.name" alt="Meter Image" class="2xl:max-h-60 md:max-h-40 pb-6" />
                            <div v-else id="attachment" class="2xl:max-h-60 md:max-h-40 pb-6">
                                <div class="hover:text-white-snow text-white-snow hover:border-gray-semilight hover:bg-cyan-opa border border-gray-semimedium py-1 px-2 flex flex-row items-baseline justify-center rounded-md gap-2 mb-[2rem]">
                                    <i class="fa-solid fa-arrow-up h-[0.75rem]"></i>
                                    <p class=""> {{this.$t('general.Upload image')}} </p>
                                </div>
                            </div>
                            <input id="file-input" type="file" style="display:none" @change="select_img"/>
                            <div class="absolute bottom-0 left-0 right-0 z-50 flex items-center justify-center">
                                <DK_Input width="fit" id="id_Meter_model" type="text" @input="this.MeterChange()" :value="this.data.Meter_model" :border="false" textPosition="center"/>
                            </div>
                        </div>

                    </div>
                    <div class="grid gap-0.5">

                        <div class="flex justify-between text-md text-white-snow font-light">
                            <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Serial nº") }}</p>
                            <DK_Input id="id_Serial_number" type="text" @input="this.MeterChange()" :value="this.data.Serial_number" :border="false" textPosition="right"/>

                        </div>
                        <div id="scoped-component" class="flex justify-between text-md text-white-snow font-light">
                            <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Period start") }}</p>
                            <Datepicker id="id_Period_start" class="modal-input-nb2 w-full text-right"
                                v-model="this.dp_vmodel" :enableTimePicker="false" vertical
                                :clearable="false" :format="this.Period_start_formated"
                                :maxDate="new Date()"/>
                        </div>
                        <div class="flex justify-between text-md text-white-snow font-light">
                            <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Period length") }}</p>
                            <DK_Input id="id_Period_length" type="text" @input="this.MeterChange()" :value="this.data.Period_length" :border="false" textPosition="right" width="full"/>
                            <p class="text-right w-fit"> &nbsp;{{ (this.data.Period_length != 1 ? this.$t("general." + "Months") : this.$t("general." + "Month")).toLowerCase() }}</p>
                        </div>

                        <div class="2xl:pt-6 pt-4 flex flex-col 2xl:gap-6 gap-4">

                            <div class="flex justify-between flex-col text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Description") }}</p>
                                <!--<textarea id="id_Description" @input="this.MeterChange()"
                                    type="text" class="modal-input-nb2 text-justify w-full overflow-y-hidden h-6"
                                    :value="this.data.Description"></textarea>-->
                                <DK_Input id="id_Description" type="text" :textarea="true" @input="this.MeterChange()" :value="this.data.Description" :border="false" textPosition="center" width="full"/>
                            </div>

                            <div class="flex flex-col justify-center text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6 w-full">{{ this.$t("general." + "Service label") }}</p>
                                <div class="flex justify-center">
                                    <div class="gap-2 grid grid-cols-10 mt-2 place-items-center">
                                        <p v-for="(data, index) in this.data.group_service" :key="index"
                                        :style="{ 'background-color': data.color}"
                                        v-on:click="this.updateService(data.id)"
                                        :class="this.getColumnClass(index, data.id)">
                                            {{ data.tag }}
                                        </p>
                                    </div>
                                </div>
                            </div>

                            <div class="flex flex-col justify-center text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Sector labels") }}</p>
                                <div class="flex gap-x-2 overflow-x-auto justify-center mt-1 mb-[2px] cursor-pointer" v-on:click="this.openSectorconfig()">
                                    <div v-for="(data_s, index_s) in this.Sector" :key="index_s" class="flex">
                                        <div v-for="(data_g, index_g) in this.data.group_sector" :key="index_g"
                                            class="inline-flex rounded-md text-white-snow font-light text-base ">
                                            <p v-if="index_s == this.data.group_sector[index_g].id" class="label-profile">
                                                {{ data_g.tag }}
                                            </p>
                                        </div>
                                    </div>
                                    <div v-if="JSON.stringify(this.Sector) == '{}'" class="label-profile opacity-30 hover:opacity-50">
                                        <i class="fa-solid fa-plus" style="font-size:1rem; color:#FFFAFA;"></i>
                                    </div>
                                </div>
                            </div>

                            <JetModal :show="this.Sectorconfig" :closeable="false">
                                <div class="p-4">
                                    <p class="text-cyan-text text-left ml-1">
                                        {{ this.$t("general." + "Sectorization") }}</p>
                                    <div
                                        class="rounded-md border border-gray-semimedium w-full bg-transparent overflow-y-scroll p-2 mt-1 text-gray-light">
                                        <div class="grid grid-cols-4 w-full place-items-center">
                                            <p>{{ this.$t("general." + "Sector") }}</p>
                                            <p>{{ this.$t("general." + "Input") }}</p>
                                            <p>{{ this.$t("general." + "Output") }}</p>
                                            <p>{{ this.$t("general." + "Control") }}</p>
                                        </div>
                                        <div class="border-b border-gray-semimedium mt-1 w-full mb-1"></div>
                                        <div class="h-[15rem] overflow-y-scroll">
                                            <div class="grid grid-cols-4 w-full place-items-center"
                                                v-for="(data, index) in this.data.group_sector" :key="index">
                                                <p>{{ data['name'] }}</p>
                                                <input v-if="this.Sector[data.id] == 'Input'"
                                                    v-on:click="this.changecheck(data['id'], 'Input')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                    :value="data['name'] + '_Input'" checked />
                                                <input v-else v-on:click="this.changecheck(data['id'], 'Input')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                    :value="data['name'] + '_Input'" />

                                                <input v-if="this.Sector[data.id] == 'Output'"
                                                    v-on:click="this.changecheck(data['id'], 'Output')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                    :value="data['name'] + '_Output'" checked />
                                                <input v-else
                                                    v-on:click="this.changecheck(data['id'], 'Output')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                    :value="data['name'] + '_Output'" />

                                                <input v-if="this.Sector[data.id] == 'Control'"
                                                    v-on:click="this.changecheck(data['id'], 'Control')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                    :value="data['name'] + '_Control'" checked />
                                                <input v-else
                                                    v-on:click="this.changecheck(data['id'], 'Control')"
                                                    class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                    :value="data['name'] + '_Control'" />

                                            </div>
                                        </div>
                                    </div>
                                    <div class="flex justify-end h-full items-end gap-4 pt-4">
                                        <div class="flex gap-2">

                                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveSectors()" v-if="this.SectorsChange_var">
                                                {{ this.$t("general.Save") }}
                                            </DK_Button>

                                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelSectors()">
                                                {{ this.$t("general.Cancel") }}
                                            </DK_Button>

                                        </div>
                                    </div>
                                </div>
                            </JetModal>
                        </div>
                    </div>

                    <div class="flex justify-end h-full items-end gap-4" v-if="this.MeterChange_var">
                        <div class="flex gap-2">

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveMeter()">
                                {{ this.$t("general.Save") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelMeter()">
                                {{ this.$t("general.Cancel") }}
                            </DK_Button>

                        </div>
                    </div>
                </div>
                <div class="2xl:col-span-3 col-span-2 text-center text-white-snow baltoro-container-r p-4 flex flex-col justify-between h-full 2xl:gap-10 gap-8">
                    <div class="flex flex-row justify-between col-span-4 px-4 text-center text-white-snow gap-4">

                        <div class="m-0 2xl:w-56 w-36">
                            <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Current period") }}</p>
                            <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                <p class="text-2xl font-sevensegment">
                                    {{ this.data.period_consumption[0] }}
                                </p>
                                <p class="pb-1"> &nbsp;m³</p>
                            </div>
                            <div class="flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                <p class="text-left whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.period_consumption[1] : parseInt(this.data.period_consumption[1].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.period_consumption[1].substring(5,7))] }}</p>
                                <p class="text-right whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.period_consumption[2] : parseInt(this.data.period_consumption[2].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.period_consumption[2].substring(5,7))] }}</p>
                            </div>
                        </div>

                        <div class="m-0 2xl:w-56 w-36">
                            <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Forecast") }}</p>
                            <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                <p class="text-2xl font-sevensegment">
                                    {{ this.data.forecast[0] }}
                                </p>
                                <p class="pb-1"> &nbsp;m³</p>
                            </div>
                            <div class="flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                <p class="text-left whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.forecast[1] : parseInt(this.data.forecast[1].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.forecast[1].substring(5,7))] }}</p>
                                <p class="text-right whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.forecast[2] : parseInt(this.data.forecast[2].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.forecast[2].substring(5,7))] }}</p>
                            </div>
                        </div>

                        <div class="m-0 2xl:w-56 w-36 ">
                            <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Last period") }}</p>
                            <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                <p class="text-2xl font-sevensegment">
                                    {{ this.data.last_period_consumption[0] }}
                                </p>
                                <p class="pb-1"> &nbsp;m³</p>
                            </div>
                            <div class="flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                <p class="text-left whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.last_period_consumption[1] : parseInt(this.data.last_period_consumption[1].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.last_period_consumption[1].substring(5,7))] }}</p>
                                <p class="text-right whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.last_period_consumption[2] : parseInt(this.data.last_period_consumption[2].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.last_period_consumption[2].substring(5,7))] }}</p> <!---->
                            </div>
                        </div>

                        <div class="m-0 2xl:w-56 w-36">
                            <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Total consumption") }}</p>
                            <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                <p class="text-2xl font-sevensegment ">
                                    {{ this.data.total_consumption }}
                                </p>
                                <p class="pb-1"> &nbsp;m³</p>
                            </div>
                            <div
                                class="invisible flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                <p class="text-left whitespace-nowrap"></p>
                                <p class="text-right whitespace-nowrap"></p>
                            </div>
                        </div>
                    </div>

                    <div class="h-full flex flex-col p-2">
                        <p class="text-white-snow font-light text-2xl text-left pl-2">
                            {{ this.$t("general." + "Daily consumption") }}
                        </p>
                        <div class="h-full cursor-crosshair" id='dailychart'></div>
                    </div>
                </div>
            </div>
        </div>

        <div v-else style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background z-0 flex flex-col gap-4 overflow-x-hidden cursor-default">
            <div class="w-full flex flex-col justify-center items-start pt-2 pb-1 gap-2">

                <div class="w-full flex flex-row justify-between items-center px-3 h-[3.25rem]">
                    <div class="w-full flex flex-col justify-start">
                        <div class="flex flex-row justify-start">
                            <p class="text-white-snow font-light text-2xl text-left">{{ this.$t('general.Profile Information') }}</p>
                        </div>
                    </div>
                    <div class="flex justify-end gap-2">
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_Readings', { id:  this.data.id })" >
                                <button type="button"
                                    class="text-white-snow button-blue hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                    <i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                                    <i class="fa-solid fa-arrow-left" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                    </div>
                </div>

                <div v-bind:class="{ 'hidden': !(this.data.RSSI == null && this.data.Battery == null)}" class="flex gap-2 whitespace-nowrap items-baseline">
                    <i class="fa-solid fa-triangle-exclamation" style="font-size:0.8rem; color:rgba(224,191,52,1);"></i>
                    <p class="font-light text-sm text-white-snow flex whitespace-nowrap">
                        {{ this.$t('text.No records were found for the device') }}
                    </p>
                </div>

                <div class="w-full flex overflow-x-auto snap-mandatory snap-x pb-2 gap-4 px-2 overflow-y-hidden">
                    <div class="snap-center col-span-1 text-center text-white-snow baltoro-container shrink-0 p-2 h-fit w-full flex justify-between flex-col 2xl:gap-10 gap-4">
                        <div>
                            <p class="text-cyan-text font-light text-lg mb-2 whitespace-nowrap w-full text-center">{{ this.$t("general." + "Gateway") }}</p>

                            <div class="grid grid-rows-1">
                                <div class="flex row-span-1 justify-between text-md pt-1 text-white-snow font-light">
                                    <div class="text-left" style="margin-top:0.2rem">
                                        <p class="text-gray-light font-semibold">Movistar</p>
                                    </div>
                                    <div class="text-right">
                                        <!-- Coverage SVG -->
                                        <i v-if="this.data.RSSI <= 110" class="DK-signal-01"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else-if="this.data.RSSI <= 100" class="DK-signal-02"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else-if="this.data.RSSI <= 85" class="DK-signal-03"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else-if="this.data.RSSI <= 70" class="DK-signal-04"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>
                                        <i v-else class="DK-signal-05"
                                            style="font-size:1.1rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:0%"></i>

                                        <!-- Battery -->
                                        <i v-if="this.data.Battery <= 2900" class="DK-Batt-25 animate-pulse"
                                            style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem;  margin-left:0.5rem; position:relative; top:10%"></i>
                                        <i v-else-if="this.data.Battery <= 3100" class="DK-Batt-50"
                                            style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                        <i v-else-if="this.data.Battery <= 3300" class="DK-Batt-75"
                                            style="font-size:1.5rem; color:#d1d1d1; margin-right:0rem; margin-left:0.5rem; position:relative; top:10%"></i>
                                        <i v-else class="DK-Batt-100"
                                            style="font-size:1.5rem; margin-right:0rem; color:#d1d1d1; margin-left:0.5rem; position:relative; top:10%"></i>
                                    </div>
                                </div>
                            </div>

                            <div class="flex justify-center items-center relative h-[15rem]" v-bind:class="{'h-[12rem]' : this.screen_width <= 768}">
                                <img v-if="this.data.type_name.indexOf('PIPE20XL') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20XL_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20L') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20W') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20P') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20P_perspec.png" />
                                <img v-else-if="this.data.type_name.indexOf('PIPE20') != -1" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />
                                <img v-else class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}"
                                    src="\assets\images\devices\PIPE20W_perspec.png" />

                                <p class="text-gray-light font-semibold text-center absolute bottom-0 left-0 right-0 z-50">{{ this.data.type_name.replace(/_/g, " ") + ' - ' + this.data.version_firmware }}</p>
                            </div>

                        </div>

                        <div class="grid">

                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Name") }}</p>
                                <DK_Input id="id_gateway_name" type="text" @input="this.GatewayChange()" :value="this.data.name" :border="false" textPosition="right"/>
                            </div>
                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "GatewayID") }}</p>
                                <DK_Input width="7rem" type="text" :value="this.data.id" :border="false" textPosition="right" :readonly="true"/>
                            </div>
                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Group") }}</p>
                                <DK_Input type="text" :value="this.data.group_name" :border="false" textPosition="right" :readonly="true"/>
                            </div>
                        </div>

                        <div class="rounded-md border border-gray-semimedium">
                            <div class="2xl:h-[15rem] h-[12rem] rounded-md" id="map" v-on:click="this.openMapconfig()"/>

                                <JetModal :show="this.Mapconfig" :closeable="false">

                                    <div class="w-full h-max flex flex-row justify-between items-center px-4 py-2 ">
                                        <div class="w-full flex flex-col justify-start">
                                            <div class="flex flex-row justify-start">
                                                <p class="text-white-snow font-light text-2xl text-left">{{ this.$t('general.Edit location') }}</p>
                                            </div>
                                        </div>
                                        <div class="flex justify-end gap-2 h-full items-start">
                                            <div class="flex items-center justify-center" v-on:click="this.CancelMap()">
                                                <i class="fa-solid fa-xmark" style="font-size:1rem; color:rgba(200, 200, 200, 0.9); "></i>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="h-[22.5rem] w-full" id="mapModal"/>

                                    <div class="flex justify-between items-center gap-x-[2.5rem] p-2 w-[90vw]">

                                        <div class="grid grid-cols-2 w-[10rem] text-sm font-light">
                                            <p class="text-left w-fit text-cyan-text">{{ this.$t("general." + "Latitude") }}:</p>
                                            <DK_Input id="id_lat" type="text" width="6rem" :value="this.data.GPS_lat" :border="false" textPosition="center" v-on:keyup="updateLocation()"/>
                                            <p class="text-left w-fit text-cyan-text">{{ this.$t("general." + "Longitude") }}:</p>
                                            <DK_Input id="id_lng" type="text" width="6rem" :value="this.data.GPS_lng" :border="false" textPosition="center" v-on:keyup="updateLocation()"/>
                                        </div>


                                        <div class="flex justify-end items-center">
                                            <div class="flex gap-2">

                                                <DK_Button color="blue" :fixedSize="true" :disabled="this.MapChange_var" v-on:click="this.SaveMap()">
                                                    {{ this.$t("general.Save") }}
                                                </DK_Button>

                                            </div>
                                        </div>
                                    </div>

                                </JetModal>
                            </div>

                        <div class="flex justify-end items-end gap-4" v-if="this.GatewayChange_var">
                            <div class="flex gap-2">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveGateway()">
                                    {{ this.$t("general.Save") }}
                                </DK_Button>

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelGateway()">
                                    {{ this.$t("general.Cancel") }}
                                </DK_Button>

                            </div>
                        </div>
                    </div>

                    <div class="snap-center col-span-1 text-center text-white-snow baltoro-container shrink-0 p-2 h-fit w-full flex justify-between flex-col 2xl:gap-10 gap-6">

                        <div>

                            <p class="text-cyan-text font-light text-lg mb-2 whitespace-nowrap w-full text-center">{{ this.$t("general." + "Meter") }}</p>

                            <div class="flex justify-center items-center relative h-[15rem] mt-[33px]" v-bind:class="{'h-[12rem]' : this.screen_width <= 768}">
                                <img id="attachment" class="2xl:max-h-60 md:max-h-40" v-bind:class="{'h-40' : this.screen_width <= 768}" :src="'../assets/images/meters/' + this.image.name" />
                                <input id="file-input" type="file" style="display:none" @change="select_img"/>

                                <div class="absolute -bottom-2 left-0 right-0 z-50 flex items-center justify-center text-gray-light text-center">
                                    <DK_Input width="fit" id="id_Meter_model" type="text" @input="this.MeterChange()" :value="this.data.Meter_model" :border="false" textPosition="center" fontWeight="semibold"/>
                                </div>

                            </div>

                        </div>
                        <div class="grid">

                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Serial nº") }}</p>
                                <DK_Input id="id_Serial_number" type="text" @input="this.MeterChange()" :value="this.data.Serial_number" :border="false" textPosition="right"/>

                            </div>
                            <div id="scoped-component" class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Period start") }}</p>
                                <Datepicker id="id_Period_start" class="modal-input-nb2 w-full text-right"
                                    v-model="this.dp_vmodel" :enableTimePicker="false" vertical
                                    :clearable="false" :format="this.Period_start_formated"
                                    :maxDate="new Date()"/>
                            </div>
                            <div class="flex justify-between text-md text-white-snow font-light">
                                <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Period length") }}</p>
                                <DK_Input id="id_Period_length" type="text" @input="this.MeterChange()" :value="this.data.Period_length" :border="false" textPosition="right" width="full"/>
                                <p class="text-right w-fit"> &nbsp;{{ (this.data.Period_length != 1 ? this.$t("general." + "Months") : this.$t("general." + "Month")).toLowerCase() }}</p>
                            </div>

                            <div class="2xl:pt-6 pt-4 flex flex-col 2xl:gap-6 gap-4">

                                <div class="flex justify-between flex-col text-md text-white-snow font-light">
                                    <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Description") }}</p>
                                    <!--<textarea id="id_Description" @input="this.MeterChange()"
                                        type="text" class="modal-input-nb2 text-justify w-full overflow-y-hidden h-6"
                                        :value="this.data.Description"></textarea>-->
                                    <DK_Input id="id_Description" type="text" :textarea="true" @input="this.MeterChange()" :value="this.data.Description" :border="false" textPosition="center" width="full"/>
                                </div>

                                <div class="flex flex-col justify-center text-md text-white-snow font-light">
                                    <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6 w-full">{{ this.$t("general." + "Service label") }}</p>
                                    <div class="flex justify-center">
                                        <div class="gap-2 grid grid-cols-10 mt-2 place-items-center">
                                            <p v-for="(data, index) in this.data.group_service" :key="index"
                                            :style="{ 'background-color': data.color}"
                                            v-on:click="this.updateService(data.id)"
                                            :class="this.getColumnClass(index, data.id)">
                                                {{ data.tag }}
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="flex flex-col justify-center text-md text-white-snow font-light">
                                    <p class="whitespace-nowrap text-left text-cyan-text 2xl:pr-6">{{ this.$t("general." + "Sector labels") }}</p>
                                    <div class="flex gap-x-2 overflow-x-auto justify-center mt-1 mb-[2px] cursor-pointer" v-on:click="this.openSectorconfig()">
                                        <div v-for="(data_s, index_s) in this.Sector" :key="index_s" class="flex">
                                            <div v-for="(data_g, index_g) in this.data.group_sector" :key="index_g"
                                                class="inline-flex rounded-md text-white-snow font-light text-base ">
                                                <p v-if="index_s == this.data.group_sector[index_g].id" class="label-profile">
                                                    {{ data_g.tag }}
                                                </p>
                                            </div>
                                        </div>
                                        <div v-if="JSON.stringify(this.Sector) == '{}'" class="label-profile opacity-30 hover:opacity-50">
                                            <i class="fa-solid fa-plus" style="font-size:1rem; color:#FFFAFA;"></i>
                                        </div>
                                    </div>
                                </div>

                                <JetModal :show="this.Sectorconfig" :closeable="false">
                                    <div class="p-4">
                                        <p class="text-cyan-text text-left ml-1">
                                            {{ this.$t("general." + "Sectorization") }}</p>
                                        <div
                                            class="rounded-md border border-gray-semimedium w-full bg-transparent overflow-y-scroll p-2 mt-1 text-gray-light">
                                            <div class="grid grid-cols-4 w-full place-items-center">
                                                <p>{{ this.$t("general." + "Sector") }}</p>
                                                <p>{{ this.$t("general." + "Input") }}</p>
                                                <p>{{ this.$t("general." + "Output") }}</p>
                                                <p>{{ this.$t("general." + "Control") }}</p>
                                            </div>
                                            <div class="border-b border-gray-semimedium mt-1 w-full mb-1"></div>
                                            <div class="h-[15rem] overflow-y-scroll">
                                                <div class="grid grid-cols-4 w-full place-items-center"
                                                    v-for="(data, index) in this.data.group_sector" :key="index">
                                                    <p>{{ data['name'] }}</p>
                                                    <input v-if="this.Sector[data.id] == 'Input'"
                                                        v-on:click="this.changecheck(data['id'], 'Input')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                        :value="data['name'] + '_Input'" checked />
                                                    <input v-else v-on:click="this.changecheck(data['id'], 'Input')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Input'"
                                                        :value="data['name'] + '_Input'" />

                                                    <input v-if="this.Sector[data.id] == 'Output'"
                                                        v-on:click="this.changecheck(data['id'], 'Output')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                        :value="data['name'] + '_Output'" checked />
                                                    <input v-else
                                                        v-on:click="this.changecheck(data['id'], 'Output')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Output'"
                                                        :value="data['name'] + '_Output'" />

                                                    <input v-if="this.Sector[data.id] == 'Control'"
                                                        v-on:click="this.changecheck(data['id'], 'Control')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                        :value="data['name'] + '_Control'" checked />
                                                    <input v-else
                                                        v-on:click="this.changecheck(data['id'], 'Control')"
                                                        class="h-4" type="radio" :id="data['name'] + '_Control'"
                                                        :value="data['name'] + '_Control'" />

                                                </div>
                                            </div>
                                        </div>
                                        <div class="flex justify-end h-full items-end gap-4 pt-4">
                                            <div class="flex gap-2">

                                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveSectors()" v-if="this.SectorsChange_var">
                                                    {{ this.$t("general.Save") }}
                                                </DK_Button>

                                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelSectors()">
                                                    {{ this.$t("general.Cancel") }}
                                                </DK_Button>

                                            </div>
                                        </div>
                                    </div>
                                </JetModal>
                            </div>
                        </div>

                        <div class="flex justify-end h-full items-end gap-4" v-if="this.MeterChange_var">
                            <div class="flex gap-2">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveMeter()">
                                    {{ this.$t("general.Save") }}
                                </DK_Button>

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelMeter()">
                                    {{ this.$t("general.Cancel") }}
                                </DK_Button>

                            </div>
                        </div>
                    </div>

                    <div class="snap-center col-span-1 text-center text-white-snow shrink-0 h-fit w-full flex justify-between flex-col 2xl:gap-10 gap-2">

                        <div class="p-2 baltoro-container w-full">
                            <p class="text-cyan-text font-light text-lg mb-2 whitespace-nowrap w-full text-center">{{ this.$t("general." + "Daily consumption") }}</p>
                            <div class="h-[20rem] cursor-crosshair" id='dailychart'></div>
                        </div>

                        <div class="flex flex-row justify-evenly col-span-2 px-4 text-center text-white-snow gap-4 baltoro-container p-2">

                            <div class="flex flex-col gap-2">
                                <div class="m-0 2xl:w-56 w-36">
                                    <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Current period") }}</p>
                                    <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                        <p class="text-2xl font-sevensegment">
                                            {{ this.data.period_consumption[0] }}
                                        </p>
                                        <p class="pb-1"> &nbsp;m³</p>
                                    </div>
                                    <div class="flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                        <p class="text-left whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.period_consumption[1] : parseInt(this.data.period_consumption[1].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.period_consumption[1].substring(5,7))] }}</p>
                                        <p class="text-right whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.period_consumption[2] : parseInt(this.data.period_consumption[2].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.period_consumption[2].substring(5,7))] }}</p>
                                    </div>
                                </div>

                                <div class="m-0 2xl:w-56 w-36">
                                    <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Forecast") }}</p>
                                    <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                        <p class="text-2xl font-sevensegment">
                                            {{ this.data.forecast[0] }}
                                        </p>
                                        <p class="pb-1"> &nbsp;m³</p>
                                    </div>
                                    <div class="flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                        <p class="text-left whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.forecast[1] : parseInt(this.data.forecast[1].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.forecast[1].substring(5,7))] }}</p>
                                        <p class="text-right whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.forecast[2] : parseInt(this.data.forecast[2].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.forecast[2].substring(5,7))] }}</p>
                                    </div>
                                </div>
                            </div>

                            <div class="flex flex-col gap-2">
                                <div class="m-0 2xl:w-56 w-36 ">
                                    <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Last period") }}</p>
                                    <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                        <p class="text-2xl font-sevensegment">
                                            {{ this.data.last_period_consumption[0] }}
                                        </p>
                                        <p class="pb-1"> &nbsp;m³</p>
                                    </div>
                                    <div class="flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                        <p class="text-left whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.last_period_consumption[1] : parseInt(this.data.last_period_consumption[1].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.last_period_consumption[1].substring(5,7))] }}</p>
                                        <p class="text-right whitespace-nowrap">{{ (this.screen_width > 1280) ? this.data.last_period_consumption[2] : parseInt(this.data.last_period_consumption[2].substring(8)) + ' ' + this.months[ - 1  + parseInt(this.data.last_period_consumption[2].substring(5,7))] }}</p> <!---->
                                    </div>
                                </div>

                                <div class="m-0 2xl:w-56 w-36">
                                    <p class="text-cyan-text font-light whitespace-nowrap">{{ this.$t("general." + "Total consumption") }}</p>
                                    <div class="w-full mt-1 rounded-md bg-cyan-opa inline-flex justify-center items-end">

                                        <p class="text-2xl font-sevensegment ">
                                            {{ this.data.total_consumption }}
                                        </p>
                                        <p class="pb-1"> &nbsp;m³</p>
                                    </div>
                                    <div
                                        class="invisible flex row-span-1 justify-between text-xs pt-1 text-gray-medium font-light">
                                        <p class="text-left whitespace-nowrap"></p>
                                        <p class="text-right whitespace-nowrap"></p>
                                    </div>
                                </div>
                            </div>

                        </div>

                    </div>
                </div>
            </div>
        </div>
    </AppLayout>
</template>

<script>
export default {
    props: [ 'data', 'user'],

    data() {
        return {
            months: [
                this.$t('general.Jan'),
                this.$t('general.Feb'),
                this.$t('general.Mar'),
                this.$t('general.Apr'),
                this.$t('general.May'),
                this.$t('general.Jun'),
                this.$t('general.Jul'),
                this.$t('general.Aug'),
                this.$t('general.Sep'),
                this.$t('general.Oct'),
                this.$t('general.Nov'),
                this.$t('general.Dec')
            ],
            imageExists: false,
            Back: localStorage.getItem('Back'),
            Mapconfig: false,
            //Serviceconfig: false,
            Sectorconfig: false,
            GPS_lat: this.data.GPS_lat,
            GPS_lng: this.data.GPS_lng,
            mapModal: undefined,
            sensor_index: 0,
            str_img: "../assets/images/markers/" + this.getMarker(this.data.Service) + ".png",
            dp_vmodel: new Date(this.data.Period_start),
            MeterChange_var: false,
            GatewayChange_var: false,
            SectorsChange_var: false,
            MapChange_var: false,
            service_id: this.data.Idservice,
            Sector: { ...this.data.Sector },
            charts: undefined,
            screen_width: 0,
            image: {
                name: this.data.image_name != '' ? this.data.image_name :'default.png',
                path: 'meters',
            },
        }
    },

    beforeCreate() {

        this.$i18n.locale = this.user.language


        if(JSON.stringify(this.data.Sector) == '[]'){
            this.data.Sector = { ...this.data.Sector }
        }

    },

    beforeMount() {
        this.screen_width = window.screen.width;
    },

    mounted() {

        this.checkImageExistence();

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        // MAPBOX ACCESS TOKEN
        mapboxgl.accessToken = 'pk.eyJ1IjoiZGF0YWtvcnVtLWRldmVsb3AiLCJhIjoiY2w0ODhqOXc2MDR1MjNjbzJ2YnZkdjNhYSJ9.pVPMnmkwOuF4DonlbNkkEw';

        const Highcharts = require('highcharts');
        require('highcharts/highcharts-more')(Highcharts);

        let Chart = {
            chart: {
                zoomType: 'x',
                backgroundColor: 'transparent',
                spacingTop: 20,
                animation: {
                    duration: 150
                },
                resetZoomButton: {
                    position: {
                        align: 'left',
                        verticalAlign: 'top',
                        x: 0,
                        y: 2.5
                    },
                    theme: {
                        r: 5.6,
                    }
                }
            },
            accessibility: {
                enabled: false
            },
            title: {
                text: ''
            },
            xAxis: {
                lineColor: '#647F8C',
                visible: true,
                labels: {
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                type: "datetime",
                dateTimeLabelFormats: {
                    week: '%m-%d',
                    month: '%Y-%m',
                    year: '%Y'
                },
            },
            yAxis: [{
                opposite: true,
                gridLineColor: '#647F8C',
                title: {
                    text: ''
                },
                labels: {
                    formatter: function () {
                        return this.pos + '  ' + this.chart.userOptions.series[0].tooltip.valueSuffix
                    },
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                visible: true,
            }],
            plotOptions: {
                column: {
                    borderWidth: 0
                }
            },
            exporting: {
                enabled: true
            },
            credits: {
                enabled: false
            },
            legend: {
                enabled: false,
                itemStyle: {
                    color: 'rgba(200, 200, 200, 0.9)',
                    opacity: 0.75,
                    fontWeight: 'light'
                },
                itemHoverStyle: {
                    color: 'rgba(200, 200, 200, 0.9)',
                    opacity: 0.75,
                    fontWeight: 'light'
                }
            },

            tooltip: {
                shared: true,
                split: false,
                backgroundColor: 'rgba(7,82,103,0.95)',
                borderRadius: 12,
                borderWidth: 1,
                borderColor: 'rgba(250, 250, 250, 0.65)',
                padding: 6,
                formatter: function () {

                    function formatDate(epochMs) {
                        const fecha = new Date(epochMs);
                        const year = fecha.getFullYear();
                        const month = String(fecha.getMonth() + 1).padStart(2, '0');
                        const day = String(fecha.getDate()).padStart(2, '0');

                        return `${year}/${month}/${day}`;
                    }

                    var s = '<b>' + '<p style="font-size:12px; line-height: 12px; font-weight: 300; color:rgba(250, 250, 250, 0.95)">' + formatDate(this.x) + ' → </p>'; //
                    $.each(this.points, function () {
                        s += '<p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.y.toFixed(3) +
                            ' ' + this.series.userOptions.tooltip.valueSuffix + '</p><br/>';
                    });


                    return s;
                },
            },
        };

        Chart.series = [{
            name: this.$t("general." + "Data period"),
            type: 'areaspline',
            data: this.data.dailydata,
            //color: "#05fff3",
            color: {
              linearGradient: {
                x1: 0,
                y1: 0,
                x2: 0,
                y2: 1
              },
              stops: [
                [0, "rgba(5,255,243, 1)"],
                [0.25, "rgba(5,255,243,0.95)"],
                [0.5, "rgba(5,255,243,0.85)"],
                [0.75, "rgba(5,255,243,0.70)"],
                [1, "rgba(5,255,243,0.5)"]
              ]
            },
            marker: {
                enabled: false
            },
            tooltip: {
                valueSuffix: 'm³'
            }
        }];

        this.charts = Highcharts.chart('dailychart', Chart);


        document.getElementById("attachment").addEventListener('click', function() {
            document.getElementById("file-input").click();
        });

        this.rechargePage();

    },

    methods: {

        rechargePage() {

            // creating map
            const map = new mapboxgl.Map({
            attributionControl: false,
            container: "map",
            style: 'mapbox://styles/datakorum-develop/cl4cu370w000v15tal53sxn9v',
            center: [this.data.GPS_lng, this.data.GPS_lat],
            zoom: 15,
            pitch: this.screen_width >= 768 ? 50 : 0,
            bearing: 0,
            interactive: false,
            });

            let img = document.createElement('img');
            img.src = this.str_img;

            let markerElement = document.createElement('div')
            markerElement.appendChild(img)

            new mapboxgl.Marker({ element: markerElement })
                .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                .addTo(map);
        },

        select_img(event){

            const formData = new FormData();
            formData.append('image', event.target.files[0]);

            let BUS_iddevice = this.data.id + '_2'

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                    method: 'post',
                    url: window.location.origin + '/api/meter/upload_image/' + this.user.id + '/' + BUS_iddevice + '/' + this.image.path,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'multipart/form-data',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: formData
                })
                    .then((response) => {

                        if(this.image.name != this.data.image_name && this.image.name != response.data){

                            axios({
                                method: 'delete',
                                url: window.location.origin + '/api/meter/delete_image/' + this.user.id + '/' + this.image.name + '/' + this.image.path,
                                headers: {
                                    'Accept': 'application/json',
                                    'Content-Type': 'application/json',
                                    'Authorization': 'Bearer ' + this.user.token
                                },
                            })
                            .then((response) => {
                                window.emitter.emit('changeLoaderStatus', false, 'orbit')
                                return ("Success!", response);
                            })
                            .catch((error) => {

                                if(error.response && error.response.status && error.response.status == 429){
                                window.alert( this.$t('text.Api attempts'));
                                }else{
                                return "Failed!", error;
                                }

                            });                        }

                        this.image.name = response.data
                        this.image.name = (response.data != '') ? response.data : 'default.png';

                        this.MeterChange()

                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    })
                    .catch((error) => {
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                        }else{
                        return "Failed!", error;
                        }

                    });
            },

        getColumnClass(index, id) {

            let colStart;

            if(this.data.group_service.length <= 5 || this.data.group_service.length === 10){
                colStart = index * 2 + 1
            } else if(this.data.group_service.length > 5 && this.data.group_service.length < 10 && this.data.group_service.length % 2 === 1){

                if(this.data.group_service.length == 7){
                    if(index < 4){
                        colStart = index * 2 + 2
                    }else{
                        colStart = (index - 4) * 2 + 3
                    }
                }else if(this.data.group_service.length == 9) {
                    if(index < 5){
                        colStart = index * 2 + 1
                    }else{
                        colStart = (index - 5) * 2 + 2
                    }
                }

            } else if(this.data.group_service.length > 5 && this.data.group_service.length < 10 && this.data.group_service.length % 2 === 0){

                if(this.data.group_service.length == 6){


                    if(index < 3){
                        colStart = index * 2 + 3
                    }else{
                        colStart = (index - 3) * 2 + 3
                    }

                }else if(this.data.group_service.length == 8) {

                    if(index < 4){
                        colStart = index * 2 + 2
                    }else{
                        colStart = (index - 4) * 2 + 2
                    }
                }

            }


            var temp = `col-start-${colStart} label-profile col-span-2`;

            if(this.service_id != id){
                temp += '  opacity-30 hover:opacity-50 hover:opacity-50';
            }



            return temp;
        },

        switchSensor(index){
            this.sensor_index = index
        },

        updateService(id) {
            this.service_id = id;
            this.MeterChange()
        },

        getServiceColor(){
            let color;

            this.data.group_service.forEach( (service, index) => {
                if(service.id == this.service_id){
                    color = service.color;
                }
            } )

            return color;
        },

        getServiceName(){
            let name;

            this.data.group_service.forEach( (service, index) => {
                if(service.id == this.service_id){
                    name = service.name;
                }
            } )

            return name;
        },

        getMarker(service){
            switch(service){
                case 'Domiciliario': return 'domiciliaryLang';
                case 'Distribución': return 'distributionLang';
                case 'Control de presión': return 'pressureLang';
                case 'Calidad de agua': return 'waterQualityLang';
                case 'Nivel de agua': return 'waterLevelLang';
            }

            return 'domiciliaryLang';
        },

        changecheck(sector_id, s_function) {

            for (var index = 0; index < this.data.group_sector.length; index++) {
                if (this.data.group_sector[index].id == sector_id) {
                    if (document.getElementById(this.data.group_sector[index].name + '_' + this.Sector[sector_id])) {
                        document.getElementById(this.data.group_sector[index].name + '_' + this.Sector[sector_id]).checked = false;
                    }
                    if (s_function != this.Sector[sector_id]) {
                        this.Sector[sector_id] = s_function;
                    } else {
                        delete this.Sector[sector_id];
                    }
                }
            }

            if(JSON.stringify(this.Sector) != JSON.stringify(this.data.Sector)) {
                this.SectorsChange_var = true
            } else {
                this.SectorsChange_var = false
            }

        },

        countProperties(obj) {
            var count = 0;

            for (var prop in obj) {
                if (obj.hasOwnProperty(prop))
                    ++count;
            }

            return count;
        },

        updateLocation(){

            this.data.GPS_lat = document.getElementById('id_lat').value
            this.data.GPS_lng = document.getElementById('id_lng').value

            this.mapModal.flyTo({
                center: [this.data.GPS_lng, this.data.GPS_lat],
                essential: true,
            });

            this.markers.forEach(marker => marker.remove());
            this.markers = [];

            let img = document.createElement('img');
            img.src = this.str_img;

            let markerElement = document.createElement('div')
            markerElement.appendChild(img)

            this.markers.push(new mapboxgl.Marker({ element: markerElement })
                .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                .addTo(this.mapModal));

        },

        openMapconfig() {
            this.Mapconfig = true;

            setTimeout(() => {

                this.mapModal = new mapboxgl.Map({
                attributionControl: false,
                container: "mapModal",
                style: 'mapbox://styles/datakorum-develop/cl4cu370w000v15tal53sxn9v',
                center: [this.data.GPS_lng, this.data.GPS_lat],
                zoom: 15,
                pitch: 50,
                bearing: 0,
                });

                this.markers = [];

                let img = document.createElement('img');
                img.src = this.str_img;

                let markerElement = document.createElement('div')
                markerElement.appendChild(img)

                this.markers.push(new mapboxgl.Marker({ element: markerElement })
                    .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                    .addTo(this.mapModal));

                this.mapModal.on("click", (event) => {

                    this.data.GPS_lat = event.lngLat.lat,
                    this.data.GPS_lng = event.lngLat.lng

                    this.mapModal.flyTo({
                        center: [this.data.GPS_lng, this.data.GPS_lat],
                        essential: true,
                    });

                    this.markers.forEach(marker => marker.remove());
                    this.markers = [];

                    this.markers.push(new mapboxgl.Marker({ element: markerElement })
                        .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
                        .addTo(this.mapModal));

                    this.MapChange_var = false;
                });

            }, 0);

        },

        openSectorconfig() {
            this.Sectorconfig = true;
        },

        CancelGateway() {
            document.getElementById('id_gateway_name').value = this.data.name
            this.GatewayChange()
        },

        CancelMap() {
            this.Mapconfig = false;

            if(this.data.GPS_lat != this.GPS_lat || this.data.GPS_lng != this.GPS_lng){
                this.data.GPS_lat = this.GPS_lat;
                this.data.GPS_lng = this.GPS_lng;
                this.rechargePage();
            }
        },

        CancelMeter() {

            document.getElementById('id_Serial_number').value = this.data.Serial_number;
            document.getElementById('id_Meter_model').value = this.data.Meter_model;
            document.getElementById('id_Period_length').value = this.data.Period_length;
            document.getElementById('id_Description').value = this.data.Description;
            this.dp_vmodel = new Date(this.data.Period_start);
            this.service_id = this.data.Idservice;
            this.Sector = { ...this.data.Sector };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'delete',
                url: window.location.origin + '/api/meter/delete_image/' + this.user.id + '/' + this.image.name + '/' + this.image.path,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
            })
            .then((response) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')
                this.image.name = (this.data.image_name != '') ? this.data.image_name : 'default.png';
                this.MeterChange()
                return ("Success!", response);
            })
            .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });

        },

        GatewayChange(){

            let bool = false;
            if(
                document.getElementById('id_gateway_name').value != this.data.name
            ){
                bool = true;
            }

            this.GatewayChange_var = bool;
        },

        MapChange(){

            let bool = false;
            var numsFilter = /^-?\d+(\.\d+)?$/;
            var latValue = parseFloat(document.getElementById('id_lat').value);
            var lngValue = parseFloat(document.getElementById('id_lng').value);

            if (
                !(document.getElementById('id_lat').value).length > 0 || !(document.getElementById('id_lng').value).length > 0
            ){
                bool = true;
            }

            if(!numsFilter.test(document.getElementById('id_lat').value) || !numsFilter.test(document.getElementById('id_lng').value)){

                bool = true;
            } else if( !(latValue >= -90 && latValue <= 90) || !(lngValue >= -90 && lngValue <= 90)){

                bool = true;
            }

            this.MapChange_var = bool;
        },

        MeterChange(){

            var numsFilter = /^\d+$/;

            if( document.getElementById('id_Serial_number') &&
                document.getElementById('id_Meter_model') &&
                document.getElementById('id_Period_length') &&
                document.getElementById('id_Description')){

                let bool = false;

                if (
                    !(document.getElementById('id_Period_length').value).length > 0 || !numsFilter.test(document.getElementById('id_Period_length').value)
                ){
                    bool = false;
                }

                else if(
                    document.getElementById('id_Serial_number').value != this.data.Serial_number ||
                    document.getElementById('id_Meter_model').value != this.data.Meter_model ||
                    document.getElementById('id_Period_length').value != this.data.Period_length ||
                    document.getElementById('id_Description').value != this.data.Description ||
                    this.compareDates(this.dp_vmodel, new Date(this.data.Period_start)) ||
                    this.service_id != this.data.Idservice ||
                    JSON.stringify(this.Sector) != JSON.stringify(this.data.Sector) ||
                    (this.image.name != this.data.image_name && this.image.name != 'default.png')
                ){
                    bool = true;
                }

                let desc = document.getElementById('id_Description').value

                this.MeterChange_var = bool;

                setTimeout(() => {
                    document.getElementById('id_Description').value = desc
                }, 0);
            }
        },

        compareDates(date1, date2) {
            const year1 = date1.getFullYear();
            const month1 = date1.getMonth();
            const day1 = date1.getDate();

            const year2 = date2.getFullYear();
            const month2 = date2.getMonth();
            const day2 = date2.getDate();

            return (year1 !== year2 || month1 !== month2 || day1 !== day2);
        },

        SaveGateway() {

            var gateway_name;
            if (document.getElementById('id_gateway_name').value != this.data.name) {
                gateway_name = document.getElementById('id_gateway_name').value;
            } else {
                gateway_name = this.data.name;
            }

            var gateway_lat = this.GPS_lat;
            var gateway_lng = this.GPS_lng;

            const data = {
                name: gateway_name,
                GPS_lat: parseFloat(gateway_lat),
                GPS_lng: parseFloat(gateway_lng)
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/gateway/edit/' + this.user.id + '/' + this.data.id,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
                .then((response) => {

                    this.data.name = gateway_name
                    this.data.GPS_lat = gateway_lat,
                    this.data.GPS_lng = gateway_lng

                    this.rechargePage();

                    this.GatewayChange();

                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                })
                .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });
        },

        SaveMeter() {

            var Serial_number;
            if (document.getElementById('id_Serial_number').value != this.data.Serial_number) {
                Serial_number = document.getElementById('id_Serial_number').value;
            } else {
                Serial_number = this.data.Serial_number;
            }

            var Meter_model;
            if (document.getElementById('id_Meter_model').value != this.data.Meter_model) {
                Meter_model = document.getElementById('id_Meter_model').value;
            } else {
                Meter_model = this.data.Meter_model;
            }

            var Period_length;
            if (document.getElementById('id_Period_length').value != this.data.Period_length) {
                Period_length = document.getElementById('id_Period_length').value;
            } else {
                Period_length = this.data.Period_length;
            }

            var Description;
            if (document.getElementById('id_Description').value != this.data.Description) {
                Description = document.getElementById('id_Description').value;
            } else {
                Description = this.data.Description;
            }

            var Period_start;
            if(this.compareDates(this.dp_vmodel, new Date(this.data.Period_start))){
                const fecha = this.dp_vmodel;

                const year = fecha.getFullYear();
                const month = String(fecha.getMonth() + 1).padStart(2, '0');
                const day = String(fecha.getDate()).padStart(2, '0');

                Period_start = `${year}-${month}-${day}`;
            } else {
                Period_start = this.data.Period_start
            }

            var image_name = (this.image.name != 'default.png') ? ( this.image.name != this.data.image_name ) ? this.image.name : this.data.image_name : '';

            const Meter_name = this.data.name + '_' + Serial_number;

            const data = {

                meter_type: '5',
                data_stats: '1',

                meter_id: Serial_number, //Serial_number
                meter_name: Meter_name, //
                meter_model: Meter_model, //Meter_model
                meter_description: Description, //Description
                meter_unit: 'm3',

                period_start: Period_start,
                period_number_month: Period_length,

                sector: this.Sector,

                idservice: this.service_id,
                image_name: image_name,
            };

            ///* FLAG BUS_iddevice */
            let BUS_iddevice = this.data.id + '_2';

            window.emitter.emit('changeLoaderStatus', true, 'orbit')


            axios({
                method: 'put',
                url: window.location.origin + '/api/meter/edit/' + this.user.id + '/' + this.data.id + '/' + BUS_iddevice,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'multipart/form-data',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
            .then((response) => {


                this.data.Serial_number = data.meter_id;
                this.data.Meter_model = data.meter_model;
                this.data.Period_length = data.period_number_month;
                this.data.Description = data.meter_description;
                this.data.Period_start = data.period_start;
                this.data.Idservice = data.idservice;
                this.data.Sector = {...data.sector};
                this.data.image_name = this.image.name

                this.dp_vmodel = new Date(this.data.Period_start);
                this.service_id = this.data.Idservice;
                this.Sector = { ...this.data.Sector };

                this.MeterChange();

                window.emitter.emit('changeLoaderStatus', false, 'orbit')

            })
            .catch((error) => {
                console.error(error)
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });        },

        Period_start_formated() {

            var date = this.dp_vmodel;
            var day = date.getDate();
            var month = date.getMonth() + 1;
            var year = date.getFullYear();

            if (month.toString().length == 1 ) month = '0' + month;
            if (day.toString().length == 1 ) day = '0' + day;

            this.MeterChange()

            return `${year}/${month}/${day}`;
        },

        SaveMap(){

            if(this.data.GPS_lat != this.GPS_lat || this.data.GPS_lng != this.GPS_lng){

                const data = {
                    name: this.data.name,
                    GPS_lat: parseFloat(this.data.GPS_lat),
                    GPS_lng: parseFloat(this.data.GPS_lng)
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'put',
                    url: window.location.origin + '/api/gateway/edit/' + this.user.id + '/' + this.data.id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                    .then((response) => {

                        this.data.GPS_lat = gateway_lat
                        this.data.GPS_lng = gateway_lng

                        this.GPS_lat = gateway_lat
                        this.GPS_lng = gateway_lng

                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    })
                    .catch((error) => {
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')

                        if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                        }else{
                        return "Failed!", error;
                        }
                    });
                this.rechargePage();

            }else {

                this.data.GPS_lat = this.GPS_lat
                this.data.GPS_lng = this.GPS_lng

            }

            this.Mapconfig = false;

        },

        SaveSectors(){
            this.Sectorconfig = false;
            this.MeterChange();
        },

        CancelSectors(){
            this.Sector = { ...this.data.Sector };
            this.Sectorconfig = false;
            this.MeterChange();
        },

        async checkImageExistence() {
            try {
                const response = await fetch(`../assets/images/meters/${this.image.name}`);
                this.imageExists = response.ok;
            } catch (error) {
                console.error('Error al verificar la existencia de la imagen', error);
            }
        },
    },
}
</script>
